Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(845)

Unified Diff: chrome/browser/ui/views/toolbar/toolbar_view.cc

Issue 1636703002: Implement MD specs for non-tabbed windows in Ash (Closed) Base URL: https://chromium.googlesource.com/chromium/src.git@master
Patch Set: fix tabstrip bottom edge Created 4 years, 11 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: chrome/browser/ui/views/toolbar/toolbar_view.cc
diff --git a/chrome/browser/ui/views/toolbar/toolbar_view.cc b/chrome/browser/ui/views/toolbar/toolbar_view.cc
index d1624fcd5b4158d8c7e07c5873429a433d16dd82..d834edc6f1e67fb590619d8c130a206c21e75749 100644
--- a/chrome/browser/ui/views/toolbar/toolbar_view.cc
+++ b/chrome/browser/ui/views/toolbar/toolbar_view.cc
@@ -688,6 +688,9 @@ void ToolbarView::UpdateBadgeSeverity(AppMenuBadgeController::BadgeType type,
}
int ToolbarView::PopupTopSpacing() const {
+ if (ui::MaterialDesignController::IsModeMaterial())
+ return 0;
+
const int kAdditionalPopupTopSpacingNonGlass = 2;
return views::NonClientFrameView::kClientEdgeThickness +
(GetWidget()->ShouldWindowContentsBeTransparent() ?
@@ -736,12 +739,14 @@ gfx::Size ToolbarView::SizeForContentSize(gfx::Size size) const {
gfx::Size(0, normal_background->height() - content_shadow_height()));
}
} else if (size.height() == 0) {
// Location mode with a 0 height location bar. If on ash, expand by one
// pixel to show a border in the title bar, otherwise leave the size as zero
// height.
const int kAshBorderSpacing = 1;
- if (browser_->host_desktop_type() == chrome::HOST_DESKTOP_TYPE_ASH)
+ if (browser_->host_desktop_type() == chrome::HOST_DESKTOP_TYPE_ASH &&
+ !ui::MaterialDesignController::IsModeMaterial()) {
size.Enlarge(0, kAshBorderSpacing);
+ }
} else {
size.Enlarge(
0, PopupTopSpacing() + views::NonClientFrameView::kClientEdgeThickness);
@@ -736,12 +739,14 @@ gfx::Size ToolbarView::SizeForContentSize(gfx::Size size) const {
}
} else if (size.height() == 0) {
- // Location mode with a 0 height location bar. If on ash, expand by one
- // pixel to show a border in the title bar, otherwise leave the size as zero
- // height.
+ // Location mode with a 0 height location bar. For pre-material design Ash,
+ // expand by one pixel to show a border in the title bar, otherwise leave
+ // the size as zero height.
const int kAshBorderSpacing = 1;

Powered by Google App Engine
This is Rietveld 408576698